osc2mqtt
########

An OSC_ to MQTT_ bridge based on pyliblo_ and `paho-mqtt`_.


.. _osc: http://opensoundcontrol.org/
.. _mqtt: http://mqtt.org/
.. _paho-mqtt: https://www.eclipse.org/paho/clients/python/
.. _pyliblo: http://das.nasophon.de/pyliblo/
